@@ -217,162 +217,11 @@ NumericVector cpp_table(int Q, IntegerVector dum){
 }
 
 
-// [[Rcpp::export]]
-IntegerVector cpp_unclassFactor(NumericVector x){
-	// x: a sorted integer vector
-
-	int N = x.size();
-
-	IntegerVector res(N);
-	int k=1;
-	res[0] = 1;
-
-	for(int i=1 ; i<N ; i++){
-		if(x(i-1)!=x(i)) k++;
-		res[i] = k;
-	}
-
-	return(res);
-}
-
-// [[Rcpp::export]]
-IntegerVector cpp_unik(NumericVector x_sorted, int k_max){
-	// x_sorted: a sorted numeric vector
-
-	int n = x_sorted.size();
-
-	IntegerVector res(k_max);
-	int k = 1;
-	res[0] = x_sorted[0];
-
-	for(int i=1 ; i<n ; i++){
-		if(x_sorted(i - 1) != x_sorted(i)){
-			res[k] = x_sorted(i);
-			k++;
-			if(k == k_max) break;
-		}
-	}
-
-	return(res);
-}
-
-
 
 //
 // Getting the cluster coefficients
 //
 
-// [[Rcpp::export]]
-NumericMatrix cpp_get_fe_2(SEXP clusterSize,
-                           SEXP i_sorted_index_j, SEXP i_sorted_sumFE,
-                           SEXP j_sorted_index_i, SEXP j_sorted_sumFE,
-                           SEXP r_cumtable_i, SEXP r_cumtable_j){
-
-	int *psize = INTEGER(clusterSize);
-	int n_i = psize[0], n_j = psize[1];
-	int nb_coef = n_i + n_j;
-
-
-	int *is_ind_j = INTEGER(i_sorted_index_j);
-	double *is_sumFE = REAL(i_sorted_sumFE);
-	int *cumtable_i = INTEGER(r_cumtable_i);
-
-	int *js_ind_i = INTEGER(j_sorted_index_i);
-	double *js_sumFE = REAL(j_sorted_sumFE);
-	int *cumtable_j = INTEGER(r_cumtable_j);
-
-	// vectors
-	vector<bool> isRef_i(n_i, false);
-	vector<bool> isRef_j(n_j, false);
-	vector<double> cluster_coef_i(n_i);
-	vector<double> cluster_coef_j(n_j);
-	vector<bool> to_visit_i(n_i, true);
-	vector<bool> to_visit_j(n_j, true);
-	vector<int> cluster_pending_i(n_i);
-	vector<int> cluster_pending_j(n_j);
-
-	int n_done = 0, n_pending_i = 0, n_pending_j = 0, i, j_start = 0, j, m, u;
-	while(n_done < nb_coef){
-
-		if(n_pending_j == 0){
-			// we set the first guy encountered to 0
-			for(j=j_start ; to_visit_j[j] == false ; j++){}
-			j_start = j + 1;
-			isRef_j[j] = true;
-			to_visit_j[j] = false;
-			n_done++;
-			cluster_coef_j[j] = 0;
-			n_pending_j = 1;
-			cluster_pending_j[0] = j;
-		}
-
-		// if(n_pending_i == 0){
-		// 	// we set the first guy encountered to 0
-		// 	for(i=i_start ; to_visit_i[i] == false ; i++){}
-		// 	i_start = i + 1;
-		// 	isRef_i[i] = true;
-		// 	to_visit_i[i] = false;
-		// 	n_done++;
-		// 	cluster_coef_i[i] = 0;
-		// 	n_pending_i = 1;
-		// 	cluster_pending_i[0] = i;
-		// }
-
-		n_pending_i = 0;
-		for(m=0 ; m<n_pending_j ; m++){
-			j = cluster_pending_j[m];
-			for(u = j == 0 ? 0 : cumtable_j[j-1] ; u<cumtable_j[j] ; u++){
-				i = js_ind_i[u];
-				if(to_visit_i[i]){
-					cluster_coef_i[i] = js_sumFE[u] - cluster_coef_j[j];
-
-					to_visit_i[i] = false;
-					n_done++;
-					cluster_pending_i[n_pending_i] = i;
-					n_pending_i++;
-				}
-			}
-		}
-
-		n_pending_j = 0;
-		for(m=0 ; m<n_pending_i ; m++){
-			i = cluster_pending_i[m];
-			for(u = i == 0 ? 0 : cumtable_i[i-1] ; u<cumtable_i[i] ; u++){
-				j = is_ind_j[u];
-				if(to_visit_j[j]){
-					cluster_coef_j[j] = is_sumFE[u] - cluster_coef_i[i];
-
-					to_visit_j[j] = false;
-					n_done++;
-					cluster_pending_j[n_pending_j] = j;
-					n_pending_j++;
-				}
-			}
-		}
-
-	}
-
-	NumericMatrix res(nb_coef, 4);
-
-	for(i=0 ; i<n_i ; i++){
-		res(i, 0) = 1;
-		res(i, 1) = i + 1;
-		res(i, 2) = cluster_coef_i[i];
-		res(i, 3) = isRef_i[i];
-	}
-
-	for(j=0 ; j<n_j ; j++){
-		res(j+n_i, 0) = 2;
-		res(j+n_i, 1) = j + 1;
-		res(j+n_i, 2) = cluster_coef_j[j];
-		res(j+n_i, 3) = isRef_j[j];
-	}
-
-	return(res);
-}
-
-
-
 // [[Rcpp::export]]
 List cpp_get_fe_gnl(int Q, int N, NumericVector sumFE, IntegerMatrix dumMat, IntegerVector cluster_sizes, IntegerVector obsCluster){
 	// This function returns a list of the cluster coefficients for each cluster
@@ -694,58 +543,6 @@ double cpp_ssq(NumericVector x){
 	return(res);
 }
 
-// [[Rcpp::export]]
-List cpp_update_dum(IntegerVector dum, int k_max){
-	// much faster than redoing unclas(factor(dum))
-
-	int n = dum.length();
-	IntegerVector update_value(k_max);
-	IntegerVector dum_new(n);
-	int total = 0;
-	int k;
-
-	// we find out who's still there
-	for(int i=0 ; i<n ; i++){
-		k = dum[i] - 1;
-		if(update_value[k] == 0){
-			update_value[k] = 1;
-			total++;
-			if(total == k_max){
-				break;
-			}
-		}
-	}
-
-	if(total == k_max){
-		for(int i=0 ; i<n ; i++){
-			dum_new[i] = dum[i];
-		}
-	} else {
-		IntegerVector adjust(k_max, 0);
-		int a = 0;
-
-		for(int k=0 ; k<k_max ; k++){
-			if(update_value[k] == 0){
-				a++;
-			}
-			adjust[k] = a;
-		}
-
-		int k;
-		for(int i=0 ; i<n ; i++){
-			k = dum[i] - 1;
-			dum_new[i] = dum[i] - adjust[k];
-		}
-	}
-
-	List res;
-	res["dum_new"] = dum_new;
-	res["keep"] = update_value;
-
-	return(res);
-}
-
-
 // [[Rcpp::export]]
 bool cpp_isConstant(NumericVector x){
 	// simple fun to see whether a variable is constant
@@ -1035,33 +832,5 @@ IntegerVector cpp_check_nested(SEXP fe_list, SEXP cluster_list, IntegerVector fe
 }
 
 
-// [[Rcpp::export]]
-NumericVector cpp_diag_XUtX(NumericMatrix X, NumericMatrix U){
-    // computes the diagonal of X %*% U %*% t(X)
-
-    int n = X.nrow();
-    int K = X.ncol();
-
-    NumericVector res(n);
-
-    for(int i=0 ; i<n ; ++i){
-
-        double res_i = 0;
-        for(int k=0 ; k<K ; ++k){
-
-            double xk = 0;
-            for(int k2=0 ; k2<K ; ++k2){
-                xk += X(i, k2) * U(k, k2);
-            }
-
-            res_i += xk * X(i,k);
-        }
-
-        res[i] = res_i;
-    }
-
-    return res;
-}
-
 
 
