@@ -20,6 +20,7 @@
 #else
     #define omp_get_thread_num() 0
     #define omp_get_num_threads() 1
+    #define omp_get_max_threads() 0
 #endif
 #include <cmath>
 #include <stdio.h>
@@ -31,6 +32,12 @@ using namespace Rcpp;
 
 // This file contains misc femlm functions parallelized with the omp library
 
+// [[Rcpp::export]]
+int get_nb_threads(){
+    int res = omp_get_max_threads();
+    return(res);
+}
+
 // [[Rcpp::export]]
 NumericVector cpppar_exp(NumericVector x, int nthreads){
 	// parallel exponentiation using omp
